Handling permissions in python code — django-authority v0.2 documentation

### Navigation

- index
- next |
- previous |
- django-authority v0.2 documentation »

# Handling permissions in python code

to be written

#### Previous topic

Check permissions in templates

#### Next topic

Handling permissions using Django’s admin interface

### Quick search

Enter search terms or a module, class or function name.

### Navigation

- index
- next |
- previous |
- django-authority v0.2 documentation »

© Copyright 2009, the django-authority team. Created using Sphinx 0.6.2.